@@ -22,6 +22,8 @@ def url_to_filename(url):
         url = url[:-1]
     # remove pardir symbols to prevent unwilling filesystem access
     url = remove_pardir_symbols(url)
+    # replace dots to underscore in filename part
+    url = replace_dots_to_underscores_at_last(url)
     return url
 
 
@@ -42,6 +44,23 @@ def remove_pardir_symbols(path, sep=os.sep, pardir=os.pardir):
     return sep.join(bits)
 
 
+def replace_dots_to_underscores_at_last(path):
+    """
+    Remove dot ('.') while a dot is treated as a special character in backends
+
+    Args:
+        path (str): A target path string
+
+    Returns:
+        str
+    """
+    if path == '':
+        return path
+    bits = path.split('/')
+    bits[-1] = bits[-1].replace('.', '_')
+    return '/'.join(bits)
+
+
 if __name__ == '__main__':
     import doctest
     doctest.testmod()
